==> haskell-aeson-qq-0.8.4-326.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-qq
version:              0.8.4
visibility:           public
id:                   aeson-qq-0.8.4-5o91CzciHFt44TiHLaaYhE
key:                  aeson-qq-0.8.4-5o91CzciHFt44TiHLaaYhE
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  9b88d2d088254dc6df609886721fd9b4
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-qq-0.8.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-qq-0.8.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-qq-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-qq
hs-libraries:         HSaeson-qq-0.8.4-5o91CzciHFt44TiHLaaYhE
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    haskell-src-meta-0.8.15-GqSWx9monJhDwN3u4roT6d parsec-3.1.16.1
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV template-haskell-2.20.0.0
    text-2.0.2 vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-qq-0.8.4-327-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-qq
version:              0.8.4
visibility:           public
id:                   aeson-qq-0.8.4-23U3OtNCM4bHq8zGSg5Y3A
key:                  aeson-qq-0.8.4-23U3OtNCM4bHq8zGSg5Y3A
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  3f46513d8745a0d9ec6ef497bad2204e
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-qq-0.8.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-qq-0.8.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-qq-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-qq
hs-libraries:         HSaeson-qq-0.8.4-23U3OtNCM4bHq8zGSg5Y3A
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    haskell-src-meta-0.8.15-5WA14dofYHdB0COx7SkwL2 parsec-3.1.16.1
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW template-haskell-2.20.0.0
    text-2.0.2 vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
